==> sd-shared-web-db-mongo-1.0.4-sources.jar: systems/dennis/shared/mongo/controller/ListItemController.java <==
package systems.dennis.shared.mongo.controller;

import org.springframework.data.domain.Page;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import systems.dennis.shared.annotations.security.Secured;
import systems.dennis.shared.annotations.security.WithRole;
import systems.dennis.shared.controller.items.AbstractListItemController;
import systems.dennis.shared.controller.items.magic.MagicRequest;
import systems.dennis.shared.mongo.service.StringIdEntity;
import systems.dennis.shared.mongo.form.DefaultForm;
import systems.dennis.shared.utils.GeneratedPojoList;

import java.util.Map;

@RestController
@Secured
public interface ListItemController<T extends StringIdEntity,E extends DefaultForm> extends AbstractListItemController<T,E, String> {

    @GetMapping("/list")
    @ResponseBody
    @WithRole
    @Override
    default ResponseEntity<Page<Map<String, Object>>> get(
                                                          @RequestParam(value = "limit", required = false) Integer limit,
                                                          @RequestParam(value = "page", required = false) Integer page) {
        return AbstractListItemController.super.get( limit, page);
    }

    @PostMapping(value = {"/root/fetch/data", "/root/fetch/data/"}, produces = "application/json", consumes = "application/json")
    @ResponseBody
    @WithRole
    @Override
    default Page<Map<String, Object>> fetchData(@RequestBody MagicRequest request) {
        return AbstractListItemController.super.fetchData(request);
    }


    @GetMapping(value = {"/root/fetch/list", "/root/fetch/list/"}, produces = "application/json")
    @ResponseBody
    @WithRole
    @Override
    default GeneratedPojoList fetchForm() {
        return AbstractListItemController.super.fetchForm();
    }
}

==> sd-shared-web-db-mongo-1.1.5-sources.jar: systems/dennis/shared/mongo/controller/ListItemController.java <==
package systems.dennis.shared.mongo.controller;

import jakarta.servlet.http.HttpServletRequest;
import org.springframework.data.domain.Page;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import systems.dennis.shared.annotations.security.Secured;
import systems.dennis.shared.annotations.security.WithRole;
import systems.dennis.shared.controller.items.AbstractListItemController;
import systems.dennis.shared.controller.items.magic.MagicRequest;
import systems.dennis.shared.mongo.form.DefaultForm;
import systems.dennis.shared.mongo.service.StringIdEntity;
import systems.dennis.shared.utils.GeneratedPojoList;

import java.util.Map;

@Secured
public interface ListItemController<T extends StringIdEntity,E extends DefaultForm> extends AbstractListItemController<T,E, String> {

    @GetMapping("/list")
    @ResponseBody
    @WithRole
    @Override
    default ResponseEntity<Page<Map<String, Object>>> get(
                                                          @RequestParam(value = "limit", required = false) Integer limit,
                                                          @RequestParam(value = "page", required = false) Integer page) {
        return AbstractListItemController.super.get( limit, page);
    }

    @PostMapping(value = {"/root/fetch/data", "/root/fetch/data/"}, produces = "application/json", consumes = "application/json")
    @ResponseBody
    @WithRole
    @Override
    default Page<Map<String, Object>> fetchData(@RequestBody MagicRequest request) {
        return AbstractListItemController.super.fetchData(request);
    }


    @GetMapping(value = {"/root/fetch/list", "/root/fetch/list/"}, produces = "application/json")
    @ResponseBody
    @WithRole
    @Override
    default GeneratedPojoList fetchForm(HttpServletRequest request) {
        return AbstractListItemController.super.fetchForm(request);
    }
}
